@@ -108,6 +108,10 @@ func (b *BuildError) Is(err error) bool {
 	return buildErr.FailureReason == b.FailureReason
 }
 
+func (b *BuildError) Unwrap() error {
+	return b.Inner
+}
+
 // MakeBuildError returns an new instance of BuildError.
 func MakeBuildError(format string, args ...interface{}) error {
 	return &BuildError{
