@@ -802,9 +802,9 @@ func (e *executor) verifyAllowedImage(image, optionName string, allowedImages, i
 
 	if len(allowedImages) != 0 {
 		e.Println()
-		e.Errorln("The", image, "is not present on list of allowed", optionName)
+		e.Errorln(fmt.Sprintf("The %q image is not present on list of allowed %s:", image, optionName))
 		for _, allowedImage := range allowedImages {
-			e.Println("-", allowedImage)
+			e.Errorln("-", allowedImage)
 		}
 		e.Println()
 	} else {
