@@ -18,7 +18,7 @@ const (
 	DockerHubWarningMessage = "Pulling GitLab Runner helper image from Docker Hub. " +
 		"Helper image is migrating to registry.gitlab.com, " +
 		"for more information see " +
-		"https://docs.gitlab.com/runner/configuration/advanced-configuration.html#migrating-helper-image-to-registrygitlabcom"
+		"https://docs.gitlab.com/runner/configuration/advanced-configuration.html#migrate-helper-image-to-registrygitlabcom"
 
 	// DockerHubName is the name of the helper image hosted in Docker Hub.
 	DockerHubName = "gitlab/gitlab-runner-helper"
