@@ -2,27 +2,30 @@ package featureflags
 
 import (
 	"strconv"
+
+	"github.com/sirupsen/logrus"
 )
 
 const (
-	CmdDisableDelayedErrorLevelExpansion string = "FF_CMD_DISABLE_DELAYED_ERROR_LEVEL_EXPANSION"
-	NetworkPerBuild                      string = "FF_NETWORK_PER_BUILD"
-	UseLegacyKubernetesExecutionStrategy string = "FF_USE_LEGACY_KUBERNETES_EXECUTION_STRATEGY"
-	UseDirectDownload                    string = "FF_USE_DIRECT_DOWNLOAD"
-	SkipNoOpBuildStages                  string = "FF_SKIP_NOOP_BUILD_STAGES"
-	ShellExecutorUseLegacyProcessKill    string = "FF_SHELL_EXECUTOR_USE_LEGACY_PROCESS_KILL"
-	ResetHelperImageEntrypoint           string = "FF_RESET_HELPER_IMAGE_ENTRYPOINT"
-	UseGoCloudWithCacheArchiver          string = "FF_USE_GO_CLOUD_WITH_CACHE_ARCHIVER"
-	UseFastzip                           string = "FF_USE_FASTZIP"
-	GitLabRegistryHelperImage            string = "FF_GITLAB_REGISTRY_HELPER_IMAGE"
-	DisableUmaskForDockerExecutor        string = "FF_DISABLE_UMASK_FOR_DOCKER_EXECUTOR"
-	EnableBashExitCodeCheck              string = "FF_ENABLE_BASH_EXIT_CODE_CHECK"
-	UseWindowsLegacyProcessStrategy      string = "FF_USE_WINDOWS_LEGACY_PROCESS_STRATEGY"
+	CmdDisableDelayedErrorLevelExpansion        string = "FF_CMD_DISABLE_DELAYED_ERROR_LEVEL_EXPANSION"
+	NetworkPerBuild                             string = "FF_NETWORK_PER_BUILD"
+	UseLegacyKubernetesExecutionStrategy        string = "FF_USE_LEGACY_KUBERNETES_EXECUTION_STRATEGY"
+	UseDirectDownload                           string = "FF_USE_DIRECT_DOWNLOAD"
+	SkipNoOpBuildStages                         string = "FF_SKIP_NOOP_BUILD_STAGES"
+	ShellExecutorUseLegacyProcessKill           string = "FF_SHELL_EXECUTOR_USE_LEGACY_PROCESS_KILL"
+	ResetHelperImageEntrypoint                  string = "FF_RESET_HELPER_IMAGE_ENTRYPOINT"
+	UseGoCloudWithCacheArchiver                 string = "FF_USE_GO_CLOUD_WITH_CACHE_ARCHIVER"
+	UseFastzip                                  string = "FF_USE_FASTZIP"
+	GitLabRegistryHelperImage                   string = "FF_GITLAB_REGISTRY_HELPER_IMAGE"
+	DisableUmaskForDockerExecutor               string = "FF_DISABLE_UMASK_FOR_DOCKER_EXECUTOR"
+	EnableBashExitCodeCheck                     string = "FF_ENABLE_BASH_EXIT_CODE_CHECK"
+	UseWindowsLegacyProcessStrategy             string = "FF_USE_WINDOWS_LEGACY_PROCESS_STRATEGY"
+	SkipDockerMachineProvisionOnCreationFailure string = "FF_SKIP_DOCKER_MACHINE_PROVISION_ON_CREATION_FAILURE"
 )
 
 type FeatureFlag struct {
 	Name            string
-	DefaultValue    string
+	DefaultValue    bool
 	Deprecated      bool
 	ToBeRemovedWith string
 	Description     string
@@ -36,7 +39,7 @@ type FeatureFlag struct {
 var flags = []FeatureFlag{
 	{
 		Name:            CmdDisableDelayedErrorLevelExpansion,
-		DefaultValue:    "false",
+		DefaultValue:    false,
 		Deprecated:      false,
 		ToBeRemovedWith: "",
 		Description: "Disables [EnableDelayedExpansion](https://ss64.com/nt/delayedexpansion.html) for " +
@@ -44,7 +47,7 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:            NetworkPerBuild,
-		DefaultValue:    "false",
+		DefaultValue:    false,
 		Deprecated:      false,
 		ToBeRemovedWith: "",
 		Description: "Enables creation of a Docker [network per build](../executors/docker.md#networking) with " +
@@ -52,7 +55,7 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:            UseLegacyKubernetesExecutionStrategy,
-		DefaultValue:    "true",
+		DefaultValue:    true,
 		Deprecated:      false,
 		ToBeRemovedWith: "",
 		Description: "When set to `false` disables execution of remote Kubernetes commands through `exec` in " +
@@ -61,7 +64,7 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:            UseDirectDownload,
-		DefaultValue:    "true",
+		DefaultValue:    true,
 		Deprecated:      false,
 		ToBeRemovedWith: "",
 		Description: "When set to `true` Runner tries to direct-download all artifacts instead of proxying " +
@@ -71,14 +74,14 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:            SkipNoOpBuildStages,
-		DefaultValue:    "true",
+		DefaultValue:    true,
 		Deprecated:      false,
 		ToBeRemovedWith: "",
 		Description:     "When set to `false` all build stages are executed even if running them has no effect",
 	},
 	{
 		Name:            ShellExecutorUseLegacyProcessKill,
-		DefaultValue:    "false",
+		DefaultValue:    false,
 		Deprecated:      true,
 		ToBeRemovedWith: "14.0",
 		Description: "Use the old process termination that was used prior to GitLab 13.1 where only `SIGKILL`" +
@@ -86,7 +89,7 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:            ResetHelperImageEntrypoint,
-		DefaultValue:    "true",
+		DefaultValue:    true,
 		Deprecated:      true,
 		ToBeRemovedWith: "14.0",
 		Description: "Enables adding an ENTRYPOINT layer for Helper images imported from local Docker archives " +
@@ -95,7 +98,7 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:            UseGoCloudWithCacheArchiver,
-		DefaultValue:    "true",
+		DefaultValue:    true,
 		Deprecated:      true,
 		ToBeRemovedWith: "14.0",
 		Description: "Enables the use of Go Cloud to write cache archives to object storage. " +
@@ -103,14 +106,14 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:            UseFastzip,
-		DefaultValue:    "false",
+		DefaultValue:    false,
 		Deprecated:      false,
 		ToBeRemovedWith: "",
 		Description:     "Fastzip is a performant archiver for cache/artifact archiving and extraction",
 	},
 	{
 		Name:            GitLabRegistryHelperImage,
-		DefaultValue:    "false",
+		DefaultValue:    false,
 		Deprecated:      false,
 		ToBeRemovedWith: "",
 		Description: "Use GitLab Runner helper image for the Docker and " +
@@ -118,7 +121,7 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:            DisableUmaskForDockerExecutor,
-		DefaultValue:    "false",
+		DefaultValue:    false,
 		Deprecated:      false,
 		ToBeRemovedWith: "",
 		Description: "If enabled will remove the usage of `umask 0000` call for jobs executed with `docker` " +
@@ -130,7 +133,7 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:            EnableBashExitCodeCheck,
-		DefaultValue:    "false",
+		DefaultValue:    false,
 		Deprecated:      false,
 		ToBeRemovedWith: "",
 		Description: "If enabled, bash scripts don't rely solely on `set -e`, but check for a non-zero exit code " +
@@ -138,7 +141,7 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:            UseWindowsLegacyProcessStrategy,
-		DefaultValue:    "true",
+		DefaultValue:    true,
 		Deprecated:      false,
 		ToBeRemovedWith: "",
 		Description: "When disabled, processes that Runner creates on Windows (shell and custom executor) will be " +
@@ -147,21 +150,35 @@ var flags = []FeatureFlag{
 			"process setup is used. To successfully and gracefully drain a Windows Runner, this feature flag should" +
 			"be set to `false`.",
 	},
+	{
+		Name:            SkipDockerMachineProvisionOnCreationFailure,
+		DefaultValue:    false,
+		Deprecated:      false,
+		ToBeRemovedWith: "",
+		Description: "With the `docker+machine` executor, when a machine is " +
+			"not created, `docker-machine provision` runs for X amount of times. When " +
+			"this feature flag is set to `true`, it skips `docker-machine provision` " +
+			"removes the machine, and creates another machine instead.",
+	},
 }
 
 func GetAll() []FeatureFlag {
 	return flags
 }
 
-func IsOn(value string) (bool, error) {
+func IsOn(logger logrus.FieldLogger, value string) bool {
 	if value == "" {
-		return false, nil
+		return false
 	}
 
 	on, err := strconv.ParseBool(value)
 	if err != nil {
-		return false, err
+		logger.WithError(err).
+			WithField("value", value).
+			Error("Error while parsing the value of feature flag")
+
+		return false
 	}
 
-	return on, nil
+	return on
 }
