@@ -131,8 +131,9 @@ func (b *Buffer) advanceLogUnsafe() error {
 
 func (b *Buffer) limitExceededMessage() string {
 	return fmt.Sprintf(
-		"\n%sJob's log exceeded limit of %v bytes.%s\n",
-		helpers.ANSI_BOLD_RED,
+		"\n%sJob's log exceeded limit of %v bytes.\n"+
+			"Job execution will continue but no more output will be collected.%s\n",
+		helpers.ANSI_BOLD_YELLOW,
 		b.bytesLimit,
 		helpers.ANSI_RESET,
 	)
