@@ -115,10 +115,20 @@ func TestPowershell_GetConfiguration(t *testing.T) {
 			executor:         dockerWindowsExecutor,
 			expectedPassFile: false,
 		},
+		"pwsh on docker": {
+			shell:            SNPwsh,
+			executor:         "docker",
+			expectedPassFile: false,
+		},
+		"pwsh on kubernetes": {
+			shell:            SNPwsh,
+			executor:         "kubernetes",
+			expectedPassFile: false,
+		},
 		"pwsh on shell": {
 			shell:            SNPwsh,
 			executor:         "shell",
-			expectedPassFile: true,
+			expectedPassFile: false,
 		},
 	}
 
@@ -136,31 +146,23 @@ func TestPowershell_GetConfiguration(t *testing.T) {
 			shellConfig, err := shell.GetConfiguration(info)
 			require.NoError(t, err)
 			assert.Equal(t, tc.shell, shellConfig.Command)
-			assert.Equal(
-				t,
-				[]string{"-NoProfile", "-NonInteractive", "-ExecutionPolicy", "Bypass", "-Command"},
-				shellConfig.Arguments,
-			)
-			assert.Equal(
-				t,
-				[]string{
-					tc.shell,
-					"-NoProfile",
-					"-NoLogo",
-					"-InputFormat",
-					"text",
-					"-OutputFormat",
-					"text",
-					"-NonInteractive",
-					"-ExecutionPolicy",
-					"Bypass",
-					"-Command",
-					"-",
-				},
-				shellConfig.DockerCommand,
-			)
+			if tc.expectedPassFile {
+				assert.Equal(t, fileCmdArgs(), shellConfig.Arguments)
+			} else {
+				assert.Equal(t, stdinCmdArgs(), shellConfig.Arguments)
+			}
+			assert.Equal(t, PowershellDockerCmd(tc.shell), shellConfig.DockerCommand)
 			assert.Equal(t, tc.expectedPassFile, shellConfig.PassFile)
 			assert.Equal(t, "ps1", shellConfig.Extension)
 		})
 	}
 }
+
+func TestPowershellCmdArgs(t *testing.T) {
+	for _, tc := range []string{SNPwsh, SNPowershell} {
+		t.Run(tc, func(t *testing.T) {
+			args := PowershellDockerCmd(tc)
+			assert.Equal(t, append([]string{tc}, stdinCmdArgs()...), args)
+		})
+	}
+}
